==> client-java-api-fluent-16.0.2-sources.jar: io/kubernetes/client/openapi/models/V1PodListBuilder.java <==
/*
Copyright 2022 The Kubernetes Authors.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;

public class V1PodListBuilder extends V1PodListFluentImpl<V1PodListBuilder>
    implements VisitableBuilder<
        io.kubernetes.client.openapi.models.V1PodList,
        io.kubernetes.client.openapi.models.V1PodListBuilder> {
  public V1PodListBuilder() {
    this(false);
  }

  public V1PodListBuilder(Boolean validationEnabled) {
    this(new V1PodList(), validationEnabled);
  }

  public V1PodListBuilder(V1PodListFluent<?> fluent) {
    this(fluent, false);
  }

  public V1PodListBuilder(
      io.kubernetes.client.openapi.models.V1PodListFluent<?> fluent,
      java.lang.Boolean validationEnabled) {
    this(fluent, new V1PodList(), validationEnabled);
  }

  public V1PodListBuilder(
      io.kubernetes.client.openapi.models.V1PodListFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1PodList instance) {
    this(fluent, instance, false);
  }

  public V1PodListBuilder(
      io.kubernetes.client.openapi.models.V1PodListFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1PodList instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = fluent;
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withItems(instance.getItems());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    this.validationEnabled = validationEnabled;
  }

  public V1PodListBuilder(io.kubernetes.client.openapi.models.V1PodList instance) {
    this(instance, false);
  }

  public V1PodListBuilder(
      io.kubernetes.client.openapi.models.V1PodList instance, java.lang.Boolean validationEnabled) {
    this.fluent = this;
    this.withApiVersion(instance.getApiVersion());

    this.withItems(instance.getItems());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.validationEnabled = validationEnabled;
  }

  io.kubernetes.client.openapi.models.V1PodListFluent<?> fluent;
  java.lang.Boolean validationEnabled;

  public io.kubernetes.client.openapi.models.V1PodList build() {
    V1PodList buildable = new V1PodList();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setItems(fluent.getItems());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    return buildable;
  }
}

==> client-java-api-fluent-17.0.0-sources.jar: io/kubernetes/client/openapi/models/V1PodListBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Boolean;
public class V1PodListBuilder extends V1PodListFluentImpl<V1PodListBuilder> implements VisitableBuilder<V1PodList,V1PodListBuilder>{
  public V1PodListBuilder() {
    this(false);
  }
  public V1PodListBuilder(Boolean validationEnabled) {
    this(new V1PodList(), validationEnabled);
  }
  public V1PodListBuilder(V1PodListFluent<?> fluent) {
    this(fluent, false);
  }
  public V1PodListBuilder(V1PodListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new V1PodList(), validationEnabled);
  }
  public V1PodListBuilder(V1PodListFluent<?> fluent,V1PodList instance) {
    this(fluent, instance, false);
  }
  public V1PodListBuilder(V1PodListFluent<?> fluent,V1PodList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withItems(instance.getItems());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    this.validationEnabled = validationEnabled; 
  }
  public V1PodListBuilder(V1PodList instance) {
    this(instance,false);
  }
  public V1PodListBuilder(V1PodList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion());

    this.withItems(instance.getItems());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.validationEnabled = validationEnabled; 
  }
  V1PodListFluent<?> fluent;
  Boolean validationEnabled;
  public V1PodList build() {
    V1PodList buildable = new V1PodList();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setItems(fluent.getItems());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    return buildable;
  }
  
}
